/*
    ball-dW.hpp - Mlut and DT computations for weighted distances in 2D

    Original paper and sources:
      - E. Remy and E. Thiel. Medial Axis for Chamfer Distances: computing 
        Look-Up Tables and Neighbourhoods in 2D or 3D. 
        Pattern Recognition Letters, 23(6):649-661, April 2002.
        https://pageperso.lis-lab.fr/edouard.thiel/PRL2001/index.html

    CC BY-SA Edouard.Thiel@univ-amu.fr, Eric.remy@univ-amu.fr - 04/08/2023
*/

#ifndef BALL_DW_H
#define BALL_DW_H

#include "mask-lut.hpp"


struct Chamfer_weighting {
    int x, y, w;
};


class Ball_dW : public MaskLut {

  public :
    std::vector<Chamfer_weighting> g_mask;
    std::vector<Chamfer_weighting> half_mask;

    void add_weighting_in_g_mask (int x, int y, int w);
    void add_weighting_in_half_mask (int x, int y, int w);
    void add_chamfer_weighting (int x, int y, int w);

    void compute_CTg (int L, int *CTg) override;
    void compute_DTg (int L, int *CTg, int *DTg, int R) override;
    int get_greatest_radius (int L) override;
    int get_weight_a ();

    void compute_WDT (cv::Mat &img_int);
    void compute_RWDT (cv::Mat &img_int);
    void compute_level_curves (cv::Mat &img_int);

};  // class Ball_dW


#endif // BALL_DW_H

